@@ -5,6 +5,7 @@ from dataclasses import dataclass
 from leeger.model.abstract.UniqueId import UniqueId
 from leeger.model.league.Team import Team
 from leeger.model.league.Week import Week
+from leeger.model.league.YearSettings import YearSettings
 from leeger.util.JSONSerializable import JSONSerializable
 
 
@@ -13,6 +14,11 @@ class Year(UniqueId, JSONSerializable):
     yearNumber: int
     teams: list[Team]
     weeks: list[Week]
+    yearSettings: YearSettings = None
+
+    def __post_init__(self):
+        if self.yearSettings is None:
+            self.yearSettings = YearSettings()
 
     def __eq__(self, otherYear: Year) -> bool:
         """
@@ -22,6 +28,7 @@ class Year(UniqueId, JSONSerializable):
         equal = self.yearNumber == otherYear.yearNumber
         equal = equal and self.teams == otherYear.teams
         equal = equal and self.weeks == otherYear.weeks
+        equal = equal and self.yearSettings == otherYear.yearSettings
         return equal
 
     def toJson(self) -> dict:
@@ -29,5 +36,6 @@ class Year(UniqueId, JSONSerializable):
             "id": self.id,
             "yearNumber": self.yearNumber,
             "teams": [team.toJson() for team in self.teams],
-            "weeks": [week.toJson() for week in self.weeks]
+            "weeks": [week.toJson() for week in self.weeks],
+            "yearSettings": self.yearSettings.toJson()
         }
