@@ -1,4 +1,5 @@
 from dataclasses import dataclass
+from typing import Optional
 
 from leeger.util.Deci import Deci
 
@@ -52,11 +53,16 @@ class YearStatSheet:
     teamSuccess: dict[str, Deci]
     teamLuck: dict[str, Deci]
 
+    # Optional Stats
+    leagueMedianWins: Optional[dict[str, float]] = None
+    opponentLeagueMedianWins: Optional[dict[str, float]] = None
+    totalGames: Optional[dict[str, int]] = None
+
     def preferredOrderWithTitle(self) -> list[tuple[str, dict]]:
         """
         Returns all stats in the preferred order with the title for the stat.
         """
-        return [
+        response = [
             ("Games Played", self.gamesPlayed),
             ("Wins", self.wins),
             ("Losses", self.losses),
@@ -86,3 +92,11 @@ class YearStatSheet:
             ("Team Success", self.teamSuccess),
             ("Team Luck", self.teamLuck)
         ]
+
+        # add optional stats if needed
+        if self.leagueMedianWins is not None:
+            response.insert(1, ("Total Games", self.totalGames))
+            response.insert(4, ("League Median Wins", self.leagueMedianWins))
+            response.insert(5, ("Opponent League Median Wins", self.opponentLeagueMedianWins))
+
+        return response
