@@ -1,16 +1,8 @@
 from leeger.exception.InvalidYearFormatException import InvalidYearFormatException
-from leeger.model.league import Matchup
+from leeger.model.league import Matchup, YearSettings
 from leeger.model.league.Year import Year
 from leeger.util.navigator import YearNavigator
-from leeger.validate import teamValidation, weekValidation
-
-"""
-Checker Functions
-
-    - Will raise the appropriate exception if an incorrectly-formatted Year is passed.
-    - Will do nothing if a properly-formatted Year is passed.
-
-"""
+from leeger.validate import teamValidation, weekValidation, yearSettingsValidation
 
 
 def runAllChecks(year: Year) -> None:
@@ -19,6 +11,7 @@ def runAllChecks(year: Year) -> None:
     The order in which these are called matters.
     """
     checkAllTypes(year)
+    checkYearSettings(year)
     checkAllWeeks(year)
     checkAllTeams(year)
     checkForDuplicateTeams(year)
@@ -38,6 +31,13 @@ def runAllChecks(year: Year) -> None:
     checkMultiWeekMatchupsWithSameIdHaveSameTiebreakers(year)
 
 
+def checkYearSettings(year: Year) -> None:
+    """
+    Runs all checks on the given Year's YearSettings.
+    """
+    yearSettingsValidation.runAllChecks(year.yearSettings)
+
+
 def checkAllWeeks(year: Year) -> None:
     """
     Runs all checks on all Weeks.
@@ -65,6 +65,8 @@ def checkAllTypes(year: Year) -> None:
         raise InvalidYearFormatException("teams must be type 'list'.")
     if not isinstance(year.weeks, list):
         raise InvalidYearFormatException("weeks must be type 'list'.")
+    if not isinstance(year.yearSettings, YearSettings):
+        raise InvalidYearFormatException("yearSettings must be type 'YearSettings'.")
 
 
 def checkForDuplicateTeams(year: Year) -> None:
